@@ -38,6 +38,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_lambda
@@ -56,6 +58,10 @@ class WgetLayer(
         :param scope: -
         :param id: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(WgetLayer.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
 
 
